@@ -1,5 +1,5 @@
-from pdlpy.combinatorics import ncr
 from pdlpy.distribution import Distribution
+from pdlpy.math import floor, ncr
 
 
 class Binomial(Distribution):
@@ -7,7 +7,7 @@ class Binomial(Distribution):
     Discrete probability distribution of a number of successes in a sequence of independent experiments
     """
 
-    def __init__(self, n, p):
+    def __init__(self, n: int, p: float):
         """
         Parameters
         n: the size of the sequence
@@ -16,16 +16,23 @@ class Binomial(Distribution):
         self._n = n
         self._p = p
         self._mean = n * p
+        self._median = floor(n * p)
+        self._mode = floor((n + 1) * p)
         self._var = n * p * (1 - p)
 
     def __str__(self):
-        n = round(self._n, 2)
-        p = round(self._p, 2)
-        mean = round(self._mean, 2)
-        var = round(self._var, 2)
-        return f"Binomial(n={n}, p={p}, mean={mean}, var={var})"
+        return (
+            "Binomial("
+            f"n={self._n}, "
+            f"p={self._p:.2f}, "
+            f"mean={self._mean:.2f}, "
+            f"median={self._median:.2f}, "
+            f"mode={self._mode:.2f}, "
+            f"var={self._var:.2f}"
+            ")"
+        )
 
-    def pmf(self, x):
+    def pmf(self, x: int) -> float:
         """
         Probability Mass Function
 
@@ -37,7 +44,7 @@ class Binomial(Distribution):
         """
         return ncr(self._n, x) * self._p ** x * (1 - self._p) ** (self._n - x)
 
-    def cdf(self, x):
+    def cdf(self, x: int) -> float:
         """
         Cumulative Distribution Function
 
