@@ -1,4 +1,5 @@
 from pdlpy.distribution import Distribution
+from pdlpy.math import ceil, log2
 
 
 class Geometric(Distribution):
@@ -6,22 +7,29 @@ class Geometric(Distribution):
     Discrete probability distributions of the random number X of Bernoulli trials needed to get a single success
     """
 
-    def __init__(self, p):
+    def __init__(self, p: float):
         """
         Parameters
         p: the probability of the positive outcome of the experiment
         """
         self._p = p
         self._mean = 1 / p
+        self._median = ceil(-1 / log2(1 - p)) if p != 1 else 1
+        self._mode = 1
         self._var = (1 - p) / (p ** 2)
 
     def __str__(self):
-        p = round(self._p, 2)
-        mean = round(self._mean, 2)
-        var = round(self._var, 2)
-        return f"Geometric(p={p}, mean={mean}, var={var})"
+        return (
+            "Geometric("
+            f"p={self._p:.2f}, "
+            f"mean={self._mean:.2f}, "
+            f"median={self._median:.2f}, "
+            f"mode={self._mode:.2f}, "
+            f"var={self._var:.2f}"
+            ")"
+        )
 
-    def pmf(self, x):
+    def pmf(self, x: int) -> float:
         """
         Probability Mass Function
 
@@ -33,7 +41,7 @@ class Geometric(Distribution):
         """
         return (1 - self._p) ** x * self._p
 
-    def cdf(self, x):
+    def cdf(self, x: int) -> float:
         """
         Cumulative Distribution Function
 
