@@ -6,7 +6,7 @@ class Uniform(Distribution):
     Continuous distribution of a random variable X in interval [a; b] where any value of X has an equal probability
     """
 
-    def __init__(self, a, b):
+    def __init__(self, a: float, b: float):
         """
         Paramters
         a: the minimum value of X
@@ -15,16 +15,23 @@ class Uniform(Distribution):
         self._a = a
         self._b = b
         self._mean = (a + b) / 2
+        self._median = (a + b) / 2
+        self._mode = (a + b) / 2
         self._var = (b - a) ** 2 / 12
 
     def __str__(self):
-        a = round(self._a, 2)
-        b = round(self._b, 2)
-        mean = round(self._mean, 2)
-        var = round(self._var, 2)
-        return f"Uniform(a={a}, b={b}, mean={mean}, var={var})"
+        return (
+            "Uniform("
+            f"a={self._a:.2f}, "
+            f"b={self._b:.2f}, "
+            f"mean={self._mean:.2f}, "
+            f"median={self._median:.2f}, "
+            f"mode={self._mode:.2f}, "
+            f"var={self._var:.2f}"
+            ")"
+        )
 
-    def pdf(self, x=None):
+    def pdf(self, x: float) -> float:
         """
         Probability Density Function
 
@@ -36,7 +43,7 @@ class Uniform(Distribution):
         """
         return 1 / (self._b - self._a)
 
-    def cdf(self, x):
+    def cdf(self, x: float) -> float:
         """
         Cumulative Distribution Function
 
